@@ -332,6 +332,13 @@ class FriendshipViewTests(BaseTestCase):
             redirect_url = reverse('friendship_view_friends', kwargs={'username': self.user_bob.username})
             self.assertTrue(redirect_url in response['Location'])
 
+        with self.login(self.user_steve.username, self.user_pw):
+            # on POST try to accept the friendship request
+            # but I am logged in as Steve, so I cannot accept
+            # a request sent to Bob
+            response = self.client.post(url)
+            self.assertResponse404(response)
+
     def test_friendship_reject(self):
         url = reverse('friendship_reject', kwargs={'friendship_request_id': self.friendship_request.pk})
 
@@ -347,13 +354,20 @@ class FriendshipViewTests(BaseTestCase):
             redirect_url = reverse('friendship_requests_detail', kwargs={'friendship_request_id': self.friendship_request.pk})
             self.assertTrue(redirect_url in response['Location'])
 
-            # on POST accept the friendship request and redirect to the
+            # on POST reject the friendship request and redirect to the
             # friendship_requests view
             response = self.client.post(url)
             self.assertResponse302(response)
             redirect_url = reverse('friendship_request_list')
             self.assertTrue(redirect_url in response['Location'])
 
+        with self.login(self.user_steve.username, self.user_pw):
+            # on POST try to reject the friendship request
+            # but I am logged in as Steve, so I cannot reject
+            # a request sent to Bob
+            response = self.client.post(url)
+            self.assertResponse404(response)
+
     def test_friendship_cancel(self):
         url = reverse('friendship_cancel', kwargs={'friendship_request_id': self.friendship_request.pk})
 
@@ -369,13 +383,21 @@ class FriendshipViewTests(BaseTestCase):
             redirect_url = reverse('friendship_requests_detail', kwargs={'friendship_request_id': self.friendship_request.pk})
             self.assertTrue(redirect_url in response['Location'])
 
-            # on POST accept the friendship request and redirect to the
+            # on POST try to cancel the friendship request
+            # but I am logged in as Bob, so I cannot cancel
+            # a request made by Steve
+            response = self.client.post(url)
+            self.assertResponse404(response)
+
+        with self.login(self.user_steve.username, self.user_pw):
+            # on POST cancel the friendship request and redirect to the
             # friendship_requests view
             response = self.client.post(url)
             self.assertResponse302(response)
             redirect_url = reverse('friendship_request_list')
             self.assertTrue(redirect_url in response['Location'])
 
+
     def test_friendship_requests_detail(self):
         url = reverse('friendship_requests_detail', kwargs={'friendship_request_id': self.friendship_request.pk})
 
